Column<TType, TModel> class abstract

Abstract definition for each column

Implementers

Constructors

Column({required String name, required bool nullable, required bool isIdentity, required String datatype, required TType getDbValue(Map<String, Map<String, dynamic>> row), required TType getModelValue(TModel model)})

Properties

datatype → String
final
getDbValue → TType Function(Map<String, Map<String, dynamic>> row)
final
getModelValue → TType Function(TModel model)
final
hashCode → int
The hash code for this object.
no setterinherited
isIdentity → bool
final
name → String
final
nullable → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited