DbConnectionValues class

Constructors

DbConnectionValues({required String username, required String password, required String db, required int port, required String host})

Properties

db → String
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
password → String
final
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited