WhereClauseCalculator class

Constructors

WhereClauseCalculator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
substitutionValue ↔ int
getter/setter pair

Methods

getNextSubstitutionValue() → int
getWhereFromCommand(ClauseSuper clause, {SqlRequest sqlRequest = const SqlRequest("", {}), bool isSubCmd = false}) → SqlRequest
generate 'where' clause
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited